ui = {}

function ui.load()
	ui.W = love.graphics.getWidth()
	ui.H = love.graphics.getHeight()
	ui.K = ui.W/1280
	
	ui.defaultFont = love.graphics.newFont(14*ui.K)
	ui.pixelFont = love.graphics.newFont('fonts/Pixeltype.ttf', 40*ui.K)
	
	ui.startScreenPC = love.graphics.newImage('textures/ui/startscreenpc.png')
	ui.startScreenMob = love.graphics.newImage('textures/ui/startscreenmob.png')
	ui.menu = love.graphics.newImage('textures/ui/menu.png')
	ui.pause = love.graphics.newImage('textures/ui/pause.png')
	
	ui.controls1 = love.graphics.newImage('textures/ui/controls1.png')
	ui.controls1W = ui.controls1:getWidth()
	ui.controls1H = ui.controls1:getHeight()
	ui.controls2 = love.graphics.newImage('textures/ui/controls2.png')
	ui.controls2W = ui.controls2:getWidth()
	ui.controls2H = ui.controls2:getHeight()
	
	ui.restartHintPC = love.graphics.newImage('textures/ui/restarthintpc.png')
	ui.restartHintMob = love.graphics.newImage('textures/ui/restarthintmob.png')
	
	ui.sound = love.graphics.newImage('textures/ui/sound.png')
	ui.music = love.graphics.newImage('textures/ui/music.png')
	ui.noAudio = love.graphics.newImage('textures/ui/noaudio.png')
	
	ui.muteSound = false
	ui.muteMusic = false
	ui.showInfo = false
	ui.showInfoMobile = false
	
	ui.mouseOverLevel = false
	
	ui.horn = love.audio.newSource('sound/horn.ogg', 'static')
	ui.hornPlayed = {}
	ui.startTimer = 3
	for n = 1, ui.startTimer+1, 1 do
		ui.hornPlayed[n] = false
	end
	ui.gameTimer = 0
	ui.endTimer = 4
	ui.blackoutTimer = 0
	
	ui.playerMarker = {}
	ui.playerMarker[1] = love.graphics.newImage('textures/monkey/p1marker.png')
	ui.playerMarker[2] = love.graphics.newImage('textures/monkey/p2marker.png')
	
	ui.controls = {}
	ui.controls.r = love.graphics.getHeight()/4
	for n = 1, 2, 1 do
		ui.controls[n] = {}
		ui.controls[n].x = 0
		ui.controls[n].y = 0
	end
	
	function ui.restart()
		ui.mouseOverLevel = false
		ui.startTimer = 3
		for n = 1, ui.startTimer+1, 1 do
			ui.hornPlayed[n] = false
		end
		ui.gameTimer = 0
		ui.endTimer = 4
		ui.blackoutTimer = 0
		
		monkey.hat = {}
		monkey.hat.count = 4
		for n = 1, monkey.hat.count do
			monkey.hat[n] = {}
			monkey.hat[n].img = love.graphics.newImage('textures/monkey/hat/'..n..'.png')
			monkey.hat[n].w = monkey.hat[n].img:getWidth()
			monkey.hat[n].h = monkey.hat[n].img:getHeight()
		end
		
		monkey.hat[2].yO = 4*ui.K
		monkey.hat[3].yO = 4*ui.K
		monkey.hat[4].yO = -16*ui.K
	
		for n = 1, monkey.hat.count do
			if monkey.hat[n].xO == nil then
				monkey.hat[n].xO = 0
			end
			if monkey.hat[n].yO == nil then
				monkey.hat[n].yO = 0
			end
		end
		
		for n = 1, monkey.numOf, 1 do
			monkey[n] = {}
			
			monkey[n].walking = newAnimation(monkey.walkingSS, monkey.width/ui.K, monkey.height/ui.K, 0.2, 0)
			
			monkey[n].moving = false
			
			monkey[n].xVel = 0
			monkey[n].yVel = 0
			monkey[n].direction = 1
			monkey[n].hp = 100
			monkey[n].alive = true
			monkey[n].grenadeCD = 0
			monkey[n].walkingSound = {}
			monkey[n].walkingSound[1] = love.audio.newSource('sound/walk1.ogg', 'static')
			monkey[n].walkingSound[1]:setVolume(0.3)
			monkey[n].walkSoundTimer = 0
			monkey[n].jumpingSound = {}
			monkey[n].jumpingSound[1] = love.audio.newSource('sound/jump1.ogg', 'static')
			monkey[n].jumpingSound[1]:setVolume(0.5)
			
			monkey[n].hat = love.math.random(0, monkey.hat.count)
		end
		
		monkey.endTimer = 1
		
		monkey[1].moveLeft = 'a'
		monkey[1].moveRight = 'd'
		monkey[1].jump = 'w'
		monkey[1].throwL = 'lctrl'
		monkey[1].throwR = 'space'
		monkey[1].clr = {15, 0, 150, 200}
		monkey[1].moveJX = ui.W*0.1
		monkey[1].grenadeJX = ui.W*0.1
		
		monkey[2].moveLeft = 'kp4'
		monkey[2].moveRight = 'kp6'
		monkey[2].jump = 'kp8'
		monkey[2].throwL = 'right'
		monkey[2].throwR = 'kpenter'
		monkey[2].clr = {150, 0, 15, 200}
		monkey[2].moveJX = ui.W*0.9
		monkey[2].grenadeJX = ui.W*0.9
	
		grenade.numOf = 0
		
		if opSys == 'Windows' then
			level.load0()
			gamestate = 'menu'
		elseif opSys == 'Android' then
			level.load1()
			gamestate = 'wait'
		end
	end
	
	ui.click = love.audio.newSource('sound/click.ogg', 'static')
	
	function ui.playClick()
		if not ui.muteSound then
			ui.click:stop()
			ui.click:setPitch(1)
			ui.click:play()
		end
	end
	function ui.playUnclick()
		if not ui.muteSound then
			ui.click:stop()
			ui.click:setPitch(1.1)
			ui.click:play()
		end
	end
end

function ui.update(dt)
	if opSys == 'Android' then
		touches = love.touch.getTouches()
	end
	
	if gamestate == 'startScreen' then
		if opSys == 'Windows' then
			if (love.mouse.isDown(1) and not (love.mouse.getX() > 1220 and love.mouse.getY() < 30))
			or love.keyboard.isDown('return') then
				gamestate = 'menu'
				ui.playClick()
			end
		end
	end
	
	function ui.startScreenSkipMob(id, x, y, dx, dy)
		if gamestate == 'startScreen' then
			gamestate = 'wait'
			level.load1()
		end
	end
	
	if gamestate == 'wait' then
		ui.startTimer = ui.startTimer - dt
		
		--Гудок
		for n = 1, 3, 1 do
			if ui.startTimer < n and not ui.hornPlayed[n] then
				ui.horn:stop()
				ui.horn:setPitch(1)
				ui.horn:setVolume(0.5)
				if not ui.muteSound then
					ui.horn:play()
				end
				ui.hornPlayed[n] = true
			end
		end
		
		if ui.startTimer <= 0 then
			gamestate = 'playing'
		end
	end
	
	if gamestate == 'playing' then
		--Гудок
		if not ui.hornPlayed[4] then
			ui.horn:stop()
			ui.horn:setPitch(1.1)
			if not ui.muteSound then
				ui.horn:play()
			end
			ui.hornPlayed[4] = true
		end
		
		ui.gameTimer = ui.gameTimer + dt
	end
	
	if gamestate == 'ended' then
		ui.endTimer = ui.endTimer - dt
	end
	
	function ui.pauseExit(x, y, mb)
		if mb == 1 and gamestate == 'pause' then
			gamestate = gamestateBefore
			ui.playClick()
			love.audio.setVolume(0.2)
		end
	end
	
	--Вход в паузу при потере фокуса
	function love.focus(f)
		if (not f) and gamestate ~= 'pause' then
			gamestateBefore = gamestate
			gamestate = 'pause'
			love.audio.setVolume(0)
		end
	end
	
	function ui.info(key)
		if key == 'f1' then
			ui.showInfo = not ui.showInfo
		end
	end
	
	function ui.infoMob(id, x, y, dx, dy)
		if y < ui.H/8 then
			ui.showInfoMobile = not ui.showInfoMobile
		end
	end
	
	if gamestate == 'ended' then
		if opSys == 'Windows' then
			if love.mouse.isDown(1) or love.keyboard.isDown('return') then
				ui.restart()
				love.audio.stop()
				ui.playClick()
			end
		end
	end
	
	function ui.restartMob(id, x, y, dx, dy)
		if gamestate == 'ended' then
			ui.restart()
			love.audio.stop()
			ui.playClick()
		end
	end
	
	if gamestate == 'menu' then
		if opSys == 'Windows' then
			if love.mouse.getX() > 80*ui.K and love.mouse.getX() < 240*ui.K and love.mouse.getY() > 560*ui.K then
				if not ui.mouseOverLevel then
					level.load1()
					ui.mouseOverLevel = true
					ui.playClick()
				end
			elseif love.mouse.getX() > 320*ui.K and love.mouse.getX() < 480*ui.K and love.mouse.getY() > 560*ui.K then
				if not ui.mouseOverLevel then
					level.load2()
					ui.mouseOverLevel = true
					ui.playClick()
				end
			elseif love.mouse.getX() > 560*ui.K and love.mouse.getX() < 720*ui.K and love.mouse.getY() > 560*ui.K then
				if not ui.mouseOverLevel then
					level.load3()
					ui.mouseOverLevel = true
					ui.playClick()
				end
			elseif love.mouse.getX() > 800*ui.K and love.mouse.getX() < 960*ui.K and love.mouse.getY() > 560*ui.K then
				if not ui.mouseOverLevel then
					level.load4()
					ui.mouseOverLevel = true
					ui.playClick()
				end
			elseif love.mouse.getX() > 1040*ui.K and love.mouse.getX() < 1200*ui.K and love.mouse.getY() > 560*ui.K then
				if not ui.mouseOverLevel then
					level.load5()
					ui.mouseOverLevel = true
					ui.playClick()
				end
			elseif world.currentLevel ~= 0 then
				level.load0()
				ui.mouseOverLevel = false
				ui.playUnclick()
			end
		elseif opSys == 'Android' then
			for n, id in ipairs(touches) do
				local x, y = love.touch.getPosition(id)
				if x > 80*ui.K and x < 240*ui.K and y > 560*ui.K then
					if not ui.mouseOverLevel then
						level.load1()
						ui.mouseOverLevel = true
						ui.playClick()
					end
				elseif x > 320*ui.K and x < 480*ui.K and y > 560*ui.K then
					if not ui.mouseOverLevel then
						level.load2()
						ui.mouseOverLevel = true
						ui.playClick()
					end
				elseif x > 560*ui.K and x < 720*ui.K and y > 560*ui.K then
					if not ui.mouseOverLevel then
						level.load3()
						ui.mouseOverLevel = true
						ui.playClick()
					end
				elseif x > 800*ui.K and x < 960*ui.K and y > 560*ui.K then
					if not ui.mouseOverLevel then
						level.load4()
						ui.mouseOverLevel = true
						ui.playClick()
					end
				elseif x > 1040*ui.K and x < 1200*ui.K and y > 560*ui.K then
					if not ui.mouseOverLevel then
						level.load5()
						ui.mouseOverLevel = true
						ui.playClick()
					end
				elseif world.currentLevel ~= 0 then
					level.load0()
					ui.mouseOverLevel = false
					ui.playUnclick()
				end
			end
		end
	end
	
	function ui.levelSelectKey(key)
		if gamestate == 'menu' then
			if key == 'return' then
				gamestate = 'wait'
				ui.playClick()
			end
		end
	end
	
	function ui.levelSelect(x, y, mb)
		if gamestate == 'menu' then
			if mb == 1 then
				if ui.mouseOverLevel then
					gamestate = 'wait'
					ui.playClick()
				--[[elseif not (x > 1220 and y < 30) then
					level.load0()]]
				end
			end
		end
	end
	
	function ui.levelSelectMob(id, x, y, dx, dy)
		if ui.mouseOverLevel and gamestate == 'menu' then
			gamestate = 'wait'
			ui.playClick()
		end
	end
	
	function ui.mute(x, y, mb)
		if mb == 1 then
			if x > 1220*ui.K and x < 1240*ui.K and y < 30*ui.K then
				ui.muteSound = not ui.muteSound
				ui.playClick()
			end
			if x > 1250*ui.K and x < 1270*ui.K and y < 30*ui.K then
				ui.muteMusic = not ui.muteMusic
				ui.playClick()
			end
		end
	end
end

function ui.draw()
	for n = 1, monkey.numOf, 1 do
		if monkey[n].alive then
			love.graphics.draw(ui.playerMarker[n], monkey[n].x - 14*ui.K, monkey[n].y - 118*ui.K, 0, ui.K, ui.K)
		end
	end
	
	love.graphics.setColor(monkey[1].clr)
	love.graphics.rectangle('fill', 0, 710*ui.K, 640/100*monkey[1].hp*ui.K, 10*ui.K)
	love.graphics.setColor(monkey[2].clr)
	love.graphics.rectangle('fill', (1280 - 640*monkey[2].hp/100)*ui.K, 710*ui.K, 640*ui.K, 10*ui.K)
	love.graphics.setColor(255, 255, 255)
	
	--[[if gamestate == 'menu' or gamestate == 'startScreen' then
		love.graphics.setColor(150, 150, 150, 200)
		love.graphics.rectangle('fill', 0, 0, love.window.getWidth(), love.window.getHeight())
		love.graphics.setColor(255, 255, 255)
	end]]
	
	if gamestate == 'menu' or gamestate == 'wait' then
		if opSys == 'Windows' then
			love.graphics.setColor(255, 255, 255, 200)
			love.graphics.draw(ui.menu, 0, math.abs(ui.startTimer*300 - 900)*ui.K, 0, ui.K, ui.K)
		end
		love.graphics.setColor(255, 255, 255)
	end
	
	if gamestate == 'startScreen' then
		if opSys == 'Windows' then
			love.graphics.draw(ui.startScreenPC, 0, 0, 0, ui.K, ui.K)
		elseif opSys == 'Android' then
			love.graphics.draw(ui.startScreenMob, 0, 0, 0, ui.K, ui.K)
		end
		love.graphics.setFont(ui.pixelFont)
		love.graphics.print('v '..version, 10, 10)
		love.graphics.setFont(ui.defaultFont)
	end
	
	if gamestate == 'wait' then
		if world.currentLevel == 0 then
			love.graphics.setColor(255, 255, 255)
		else
			love.graphics.setColor(255, 255, 255, ui.startTimer*85)
		end
		if opSys == 'Windows' then
			love.graphics.draw(ui.controls1, monkey[1].x+50, monkey[1].y, 0, 1, 1, ui.controls1W/2, ui.controls1H + monkey.height)
			love.graphics.draw(ui.controls2, monkey[2].x, monkey[2].y, 0, 1, 1, ui.controls2W/2, ui.controls2H + monkey.height)
		end
		love.graphics.setColor(255, 255, 255)
	end
	
	if gamestate == 'playing' then
		if world.currentLevel == 0 then
			if opSys == 'Windows' then
				love.graphics.setColor(255, 255, 255)
				love.graphics.draw(ui.controls1, monkey[1].x+50, monkey[1].y, 0, 1, 1, ui.controls1W/2, ui.controls1H + monkey.height)
				love.graphics.draw(ui.controls2, monkey[2].x, monkey[2].y, 0, 1, 1, ui.controls2W/2, ui.controls2H + monkey.height)
			end
		end
	end
	
	if gamestate == 'ended' then
		if ui.endTimer > 1 then
			love.graphics.setColor(255, 255, 255, 255/ui.endTimer)
		else
			love.graphics.setColor(255, 255, 255)
		end
		if opSys == 'Windows' then
			love.graphics.draw(ui.restartHintPC, 0, 0, 0, ui.K, ui.K)
		elseif opSys == 'Android' then
			love.graphics.draw(ui.restartHintMob, 0, 0, 0, ui.K, ui.K)
		end
		love.graphics.setColor(255, 255, 255)
	end
	
	if gamestate == 'pause' then
		love.graphics.draw(ui.pause, 0, 0, 0, ui.K, ui.K)
	end
	
	love.graphics.draw(ui.music, 1250*ui.K, 10*ui.K, 0, ui.K, ui.K)
	if ui.muteMusic then
		love.graphics.draw(ui.noAudio, 1250*ui.K, 10*ui.K, 0, ui.K, ui.K)
	end
	
	love.graphics.draw(ui.sound, 1220*ui.K, 10*ui.K, 0, ui.K, ui.K)
	if ui.muteSound then
		love.graphics.draw(ui.noAudio, 1220*ui.K, 10*ui.K, 0, ui.K, ui.K)
	end
	
	if opSys == 'Android' then
		if gamestate == 'playing' or gamestate == 'ended' or gamestate == 'wait' then
			love.graphics.setColor(100, 100, 100, 100)
			love.graphics.arc('fill', ui.W*0.1, ui.H-ui.H/8, ui.H/8, -math.pi, 0)
			love.graphics.arc('fill', ui.W*0.9, ui.H-ui.H/8, ui.H/8, -math.pi, 0)
			
			love.graphics.circle('fill', ui.W*0.1, ui.H/2, ui.H/8)
			love.graphics.circle('fill', ui.W*0.9, ui.H/2, ui.H/8)
		end
		
		if ui.showInfoMobile then
			love.graphics.setFont(ui.defaultFont)
			love.graphics.setColor(130, 130, 130)
			love.graphics.print('v'..version..'\n'..love.timer.getFPS()..'\nlevel: '..world.currentLevel..'\n')
			
			for n = 1, monkey.numOf, 1 do
				love.graphics.setColor(monkey[n].clr)
				love.graphics.setFont(ui.defaultFont)
				love.graphics.print(math.floor(monkey[n].hp), monkey[n].x, monkey[n].y-monkey.height*2)
			end
		end
		love.graphics.setColor(255, 255, 255)
	end
	
	if ui.showInfo then
		love.graphics.setColor(100, 100, 100, 200)
		love.graphics.rectangle('fill', 0, 0, 200, 720)
		love.graphics.setColor(255, 255, 255)
		love.graphics.print('v'..version..'\n'..love.timer.getFPS()..'\n'..love.mouse.getX()..';'..love.mouse.getY()..'\n'..gamestate..'\n'..tostring(gamestateBefore)..'\n'..monkey.endTimer)
		
		for n = 1, monkey.numOf, 1 do
			love.graphics.setColor(monkey[n].clr)
			love.graphics.setPointSize(5)
			love.graphics.points(monkey[n].x, monkey[n].y)
			love.graphics.setPointSize(1)
			
			love.graphics.print(math.floor(monkey[n].hp), monkey[n].x, monkey[n].y - monkey.height - 10)
			love.graphics.setColor(255, 255, 255)
		end
		
		for g = 1, grenade.numOf, 1 do
			if not grenade[g].blewUp then
				love.graphics.setColor(0, 255, 0)
				love.graphics.setPointSize(5)
				love.graphics.points(grenade[g].x, grenade[g].y)
				love.graphics.setPointSize(1)
				
				love.graphics.print(math.floor(grenade[g].timer*100)..'\n'..math.floor((grenade[g].xVel^2+grenade[g].yVel^2)^0.5), grenade[g].x, grenade[g].y)
				love.graphics.circle('line', grenade[g].x, grenade[g].y, 200)
				love.graphics.setColor(255, 255, 255)
			end
		end
	end
end